# Kipp3

Only support Python 3.8+

| ![kipp3](https://s3.laisky.com/uploads/2019/06/nolan-comic-ft.jpg)
| :---------------------------------------------------------------:
|                       Humanistic Utilities

[![versions](https://img.shields.io/badge/version-v0.0.2-blue.svg)]()
[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)
[![PyPI version](https://badge.fury.io/py/kipp3.svg)](https://badge.fury.io/py/kipp3)
[![Commitizen friendly](https://img.shields.io/badge/commitizen-friendly-brightgreen.svg)](http://commitizen.github.io/cz-cli/)

---

[Github](https://github.com/Laisky/kipp/tree/master/kipp)

## Document

TBD

---

## Install

Run:

```sh
$ pip install kipp3
```
